@@ -1,4 +1,4 @@
-/*  $Id: weather-summary.h 7588 2009-06-16 07:06:04Z colin $
+/*  $Id: weather-summary.h 7767 2009-07-23 09:11:00Z colin $
  *
  *  Copyright (c) 2003-2007 Xfce Development Team
  * 
@@ -22,7 +22,7 @@
 
 G_BEGIN_DECLS
 
-GtkWidget * create_summary_window (xml_weather * data, units unit);
+GtkWidget * create_summary_window (xfceweather_data *data);
 
 G_END_DECLS
 #endif
